@@ -1,6 +1,6 @@
 ;;; tramp-fish.el --- Tramp access functions for FISH protocol
 
-;; Copyright (C) 2006, 2007 Free Software Foundation, Inc.
+;; Copyright (C) 2006, 2007, 2008 Free Software Foundation, Inc.
 
 ;; Author: Michael Albinus <michael.albinus@gmx.de>
 ;; Keywords: comm, processes
@@ -380,13 +380,13 @@ pass to the OPERATION."
       ;; would otherwise use backslash.  `default-directory' is
       ;; bound, because on Windows there would be problems with UNC
       ;; shares or Cygwin mounts.
-      (tramp-let-maybe directory-sep-char ?/
-	(let ((default-directory (tramp-compat-temporary-file-directory)))
-	  (tramp-make-tramp-file-name
-	   method user host
-	   (tramp-drop-volume-letter
-	    (tramp-run-real-handler 'expand-file-name
-				    (list localname)))))))))
+      (let ((directory-sep-char ?/)
+	    (default-directory (tramp-compat-temporary-file-directory)))
+	(tramp-make-tramp-file-name
+	 method user host
+	 (tramp-drop-volume-letter
+	  (tramp-run-real-handler 'expand-file-name
+				  (list localname))))))))
 
 (defun tramp-fish-handle-file-attributes (filename &optional id-format)
   "Like `file-attributes' for Tramp files."
@@ -1125,7 +1125,7 @@ connection if a previous connection has died for some reason."
 	(tramp-message vec 6 "%s" (mapconcat 'identity (process-command p) " "))
 
 	;; Check whether process is alive.
-	(set-process-sentinel p 'tramp-flush-connection-property)
+	(set-process-sentinel p 'tramp-process-sentinel)
 	(tramp-set-process-query-on-exit-flag p nil)
 
 	(tramp-process-actions p vec tramp-actions-before-shell 60)
