@@ -1,10 +1,9 @@
 ;;; tramp-util.el --- Misc utility functions to use with Tramp
-;;; -*- coding: utf-8; -*-
 
-;; Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006,
-;;   2007 Free Software Foundation, Inc.
+;; Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007,
+;;   2008 Free Software Foundation, Inc.
 
-;; Author: Kai Grojohann <kai.grossjohann@gmx.net>
+;; Author: Kai Großjohann <kai.grossjohann@gmx.net>
 ;;         Michael Albinus <michael.albinus@gmx.de>
 ;; Keywords: comm, extensions, processes
 
@@ -152,11 +151,13 @@
     (around tramp-advice-file-remote-p
 	    (filename &optional identification connected) activate)
     "Invoke `tramp-handle-file-remote-p' for Tramp files."
-    (if (eq (tramp-find-foreign-file-name-handler (expand-file-name filename))
-	    'tramp-sh-file-name-handler)
-	(setq ad-return-value
-	      (tramp-handle-file-remote-p filename identification connected))
-      ad-do-it))
+    (save-match-data
+      (if (eq (tramp-find-foreign-file-name-handler
+	       (expand-file-name filename))
+	      'tramp-sh-file-name-handler)
+	  (setq ad-return-value
+		(tramp-handle-file-remote-p filename identification connected))
+	ad-do-it)))
   (add-hook 'tramp-util-unload-hook
 	    '(lambda () (ad-unadvise 'file-remote-p))))
 
@@ -491,3 +492,8 @@ Works only for relative file names and Tramp file names."
 
 ;;; arch-tag: 500f9992-a44e-46d0-83a7-980799251808
 ;;; tramp-util.el ends here
+
+;; Local Variables:
+;; mode: Emacs-Lisp
+;; coding: utf-8
+;; End:
